@@ -260,28 +260,33 @@ data_hooks <- function(data, object, envir, param = list(), ...) {
   return(data)
 }
 
-#' Create a simulation data set from ev objects
+#' Create a simulation data set from ev objects or data frames
 #' 
-#' The goal is to take a series of event objects and combine them 
-#' into a single data set that can be passed to [data_set()]. 
+#' The goal is to take a series of event objects or data frames and combine them 
+#' into a single data frame that can be passed to [data_set()]. 
 #'
-#' @param x ev objects
-#' @param ... more ev objects
+#' @param x an ev object or data frame. 
+#' @param ... additional ev objects or data frames.
 #' 
 #' @details
-#' Each event object is added to the data frame as an `ID` or set of `ID`s  
-#' that are distinct from the `ID`s in the other event objects. Note that 
-#' including `ID` argument to the [ev()] call where `length(ID)` is greater 
-#' than one will render that set of events for all of `ID`s that are requested.
+#' Each event object or data frame is added to the data frame as an `ID` or 
+#' set of `ID`s  that are distinct from the `ID`s in the other event objects. 
+#' Note that including `ID` argument to the [ev()] call where `length(ID)` is 
+#' greater than one will render that set of events for all of `ID`s that are 
+#' requested.
 #' 
 #' When determining the case for output names, the `case` attribute for
 #' the first `ev` object passed will be used to set the case for the output
-#' data.frame.
+#' data.frame. In the event `x` is a data frame, the case of special column 
+#' names (like `amt/AMT` or `cmt/CMT`) in the first data frame will be assessed 
+#' and the case in the output data frame will be determined based on the 
+#' relative numbers of lower or upper names. 
 #'
 #' To get a data frame with one row (event) per `ID`, look at [expand.ev()].
 #' 
 #' @return 
-#' A data frame suitable for passing into [data_set()].
+#' A data frame suitable for passing into [data_set()]. The columns will appear
+#' in a standardized order. 
 #'
 #' @examples
 #' a <- ev(amt = c(100,200), cmt=1, ID = seq(3))
@@ -293,11 +298,18 @@ data_hooks <- function(data, object, envir, param = list(), ...) {
 #' d <- evd(amt = 500)
 #' 
 #' as_data_set(d, a)
-#'             
+#' 
+#' # Output will have upper case nmtran names
+#' as_data_set(
+#'   data.frame(AMT = 100, ID = 1:2), 
+#'   data.frame(amt = 200, rate = 5, cmt = 2)
+#' )
+#' 
 #' # Instead of this, use expand.ev
 #' as_data_set(ev(amt = 100), ev(amt = 200), ev(amt = 300))
 #' 
-#' @seealso [expand.ev()], [ev()]
+#' @seealso [expand.ev()], [expand.evd()], [ev()], [evd()], [uctran()], 
+#' [lctran()] 
 #'
 #' @md
 #' @rdname as_data_set
@@ -306,16 +318,22 @@ setGeneric("as_data_set", function(x,...) standardGeneric("as_data_set"))
 
 #' @rdname as_data_set
 setMethod("as_data_set", "ev", function(x, ...) {
-  other_ev <- list(...)
-  if(length(other_ev)==0) {
-    return(ev_to_ds(x)) 
-  }
-  do.call(collect_ev, c(list(x), other_ev))
+  collect_ev(x, ...)
 })
 
 #' @rdname as_data_set
-setMethod("as_data_set","data.frame", function(x, ...) {
-  as_data_set(as.ev(x) ,...)
+setMethod("as_data_set", "data.frame", function(x, ...) {
+  # Coerce the first object, then call the ev method
+  lc <- lc_tran_names(x)
+  if(lc) {
+    x <- lctran(x)
+    x <- as.ev(x)
+  } else {
+    x <- uctran(x)
+    x <- as.ev(x)
+    x <- as.evd(x)
+  }
+  as_data_set(x, ...)
 })
 
 ##' Replicate a list of events into a data set
@@ -404,7 +422,7 @@ ev_assign <- function(l, idata, evgroup, join = FALSE) {
   x[["ID"]] <- ID
   
   if(join) {
-    nu <- sapply(idata, is.numeric)
+    nu <- numeric_columns(idata)
     x <- left_join(x,idata[,nu,drop=FALSE],by="ID") 
   }
   return(x)
